@@ -5,7 +5,7 @@ use File::Basename 'dirname';
 use Cwd 'abs_path';
 use Mojolicious::Plugin::MySQLViewerLite::Command;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 has command => sub {
   my $self = shift;
@@ -24,8 +24,9 @@ sub register {
   elsif ($connector) { $self->dbi->connector($connector) }
   else { $self->dbi->dbh($dbh) }
   
-  # Add template path
+  # Add template and static path
   $self->add_template_path($app->renderer, __PACKAGE__);
+  $self->add_static_path($app->static, __PACKAGE__);
   
   # Routes
   my $r = $conf->{route} // $app->routes;
